import React from "react";
import styled from "styled-components";
import ClickToCopy from "../../util/ClickToCopy";
import LobbyPlayerList from "./LobbyPlayerList";
import DelayedButton from "../../util/DelayedButton";
import HeaderAndFooter from "../../util/HeaderAndFooter";
import { dispatch, useGameId, usePlayerName, useGameJoined } from "../../../domain/gameStore";
import JoinForm from "./JoinForm";

const InfoContainer = styled.div`
  flex: 3;
  align-self: center;

  display: flex;
  flex-flow: column nowrap;
  justify-content: center;
  align-items: center;
`

const Label = styled.span`
  padding: 0.2em;
`

const StyledDelayButton = styled(DelayedButton)`
  padding: 1em;
  margin: 0.2em;
  margin-top: 0.3em;
`

const PageContainer = styled.div`
  flex: 1;
  display: flex;
  flex-flow: row nowrap;
  justify-content: space-between;
  align-items: flex-start;
`

const getUrl = gameId => {
  const u = new URL(window.location.href);
  u.searchParams.append("join", gameId);
  return u.href;
}

const LobbyInfo = () => {
  const gameId = useGameId();
  const playerName = usePlayerName();

  return (
    <>
      <Label>Playing as {playerName}</Label>
      <Label>Use this link to invite other players:</Label>
      <Label><ClickToCopy text={getUrl(gameId)} /></Label>
      <StyledDelayButton 
        onEnd={dispatch.startRound} 
        countDownFormatter={rem => `Click to cancel, ${rem}s...`}
      >
        Start Game
      </StyledDelayButton>
    </>
  )
};

const Lobby = ({ onStart }) => {
  const joined = useGameJoined();

  return (
    <HeaderAndFooter>
      <PageContainer>
        <InfoContainer>
          {
            joined
              ? <LobbyInfo onStart={onStart}/>
              : <JoinForm />
          }
        </InfoContainer>
        <LobbyPlayerList/>
      </PageContainer>
    </HeaderAndFooter>
  )
};

export default Lobby;
